@@ -1,42 +1,42 @@
 /*
  *   This file is part of the KDE Frameworks
- * 
+ *
  *   Copyright (c) 2014 Valentin Rusu <kde@rusu.info>
- * 
+ *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Library General Public
  *   License as published by the Free Software Foundation; either
  *   version 2 of the License, or (at your option) any later version.
- * 
+ *
  *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  *   Library General Public License for more details.
- * 
+ *
  *   You should have received a copy of the GNU Library General Public License
  *   along with this library; see the file COPYING.LIB.  If not, write to
  *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *   Boston, MA 02110-1301, USA.
- * 
+ *
  */
 #ifndef _MIGRATIONWIZARD_H_
 #define _MIGRATIONWIZARD_H_
 
-#include <QtWidgets/QWizard>
+#include <QWizard>
 
 class MigrationAgent;
 
 class MigrationWizard : public QWizard {
     Q_OBJECT
 public:
-    MigrationWizard(MigrationAgent *agent);
+    explicit MigrationWizard(MigrationAgent *agent);
     ~MigrationWizard();
-    
+
     MigrationAgent *agent() const { return _agent; }
 
 public Q_SLOTS:
     void page1Updated();
-    
+
 private:
     MigrationAgent  *_agent;
 };
